# Port_reader 插件

port_reader插件从任意端口（如并行或串行端口）读取输入，并将返回值解释为被试的反应（i.e.鼠标按键反应）。

- **虚拟模式** -- 若设为‘是’, 则使用键盘收集反应。用于测试目的。
- **端口号** -- 你想用的端口号。
- **静止状态值** -- 应被解释为“无按键反应”。
- **正确反应** -- 预期反应
- **反应超时** -- 允许的最大响应时间，超过这一时间后应发出超时信号。
